@@ -7,7 +7,6 @@ from datetime import date, datetime
 from enum import Enum
 from typing import Any
 
-from pyhive import hive
 from soda.__version__ import SODA_CORE_VERSION
 from soda.common.exceptions import DataSourceConnectionError
 from soda.common.logs import Logs
@@ -27,7 +26,7 @@ def hive_connection_function(
     database: str,
     auth_method: str,
     **kwargs,
-) -> hive.Connection:
+):
     """
     Connect to hive.
 
@@ -51,6 +50,8 @@ def hive_connection_function(
     out : hive.Connection
         The hive connection
     """
+    from pyhive import hive
+
     connection = hive.connect(
         username=username, password=password, host=host, port=port, database=database, auth=auth_method
     )
@@ -70,9 +71,9 @@ def odbc_connection_function(
     cluster: str,
     server_side_parameters: dict[str, str],
     **kwargs,
-) -> pyodbc.Connection:
+):
     """
-    Connect to hive.
+    Connect to odbc.
 
     Parameters
     ----------
@@ -96,6 +97,8 @@ def odbc_connection_function(
     out : pyobc.Connection
         The connection
     """
+    import pyodbc
+
     http_path = f"/sql/protocolv1/o/{organization}/{cluster}"
     user_agent_entry = f"soda-sql-spark/{SODA_CORE_VERSION} (Databricks)"
 
@@ -118,13 +121,22 @@ def odbc_connection_function(
     return connection
 
 
+def databricks_connection_function(host: str, http_path: str, token: str, database: str, schema: str, **kwargs):
+    from databricks import sql
+
+    connection = sql.connect(
+        server_hostname=host, catalog=database, schema=schema, http_path=http_path, access_token=token
+    )
+    return connection
+
+
 class SparkConnectionMethod(str, Enum):
     HIVE = "hive"
     ODBC = "odbc"
+    DATABRICKS = "databricks"
 
 
 class SparkSQLBase(DataSource):
-
     SCHEMA_CHECK_TYPES_MAPPING: dict = {
         "string": ["character varying", "varchar"],
         "int": ["integer", "int"],
@@ -198,7 +210,7 @@ class SparkSQLBase(DataSource):
         where_clause = f"\nWHERE {table_filter_expression} \n" if table_filter_expression else ""
         return (
             f"SELECT table_name, column_name, data_type, is_nullable \n"
-            f"FROM {self.dataset_name}.INFORMATION_SCHEMA.COLUMNS"
+            f"FROM {self.schema}.INFORMATION_SCHEMA.COLUMNS"
             f"{where_clause}"
         )
 
@@ -304,14 +316,16 @@ class SparkDataSource(SparkSQLBase):
 
         self.method = data_source_properties.get("method", "hive")
         self.host = data_source_properties.get("host", "localhost")
+        self.http_path = data_source_properties.get("http_path", "http_path")
+        self.token = data_source_properties.get("token")
         self.port = data_source_properties.get("port", "10000")
         self.username = data_source_properties.get("username")
         self.password = data_source_properties.get("password")
-        self.database = data_source_properties.get("database", "default")
+        self.database = data_source_properties.get("catalog", "default")
+        self.schema = data_source_properties.get("schema", "default")
         self.auth_method = data_source_properties.get("authentication", None)
         self.configuration = data_source_properties.get("configuration", {})
         self.driver = data_source_properties.get("driver", None)
-        self.token = data_source_properties.get("token")
         self.organization = data_source_properties.get("organization", None)
         self.cluster = data_source_properties.get("cluster", None)
         self.server_side_parameters = {
@@ -323,6 +337,8 @@ class SparkDataSource(SparkSQLBase):
             connection_function = hive_connection_function
         elif self.method == SparkConnectionMethod.ODBC:
             connection_function = odbc_connection_function
+        elif self.method == SparkConnectionMethod.DATABRICKS:
+            connection_function = databricks_connection_function
         else:
             raise NotImplementedError(f"Unknown Spark connection method {self.method}")
 
@@ -336,11 +352,13 @@ class SparkDataSource(SparkSQLBase):
                 auth_method=self.auth_method,
                 driver=self.driver,
                 token=self.token,
+                schema=self.schema,
+                http_path=self.http_path,
                 organization=self.organization,
                 cluster=self.cluster,
                 server_side_parameters=self.server_side_parameters,
             )
 
-            return connection
+            self.connection = connection
         except Exception as e:
             raise DataSourceConnectionError(self.type, e)
